<?php

class EvClassRegistry
{
    /**
     * function to mimic ClassRegistry::init(), but works with our overriding model workflow
     * Pass PluginName.Model (normal models will work as normal) and it will check PluginNameModel first
     * then standard PluginName.Model
     *
     * @param   String  Model to load
     * @return  Object  Model object if found
     */
    public static function init($model)
    {
        if (strpos($model, '.') !== false) {

            list($pluginName, $modelName) = pluginSplit($model);

            // first check if we can find an 'overriding model'
            // true parameter will make it return false if none was found

            $Model = ClassRegistry::init($pluginName.$modelName, true);
            if (
                $Model !== false &&
                is_object($Model) &&
                $Model instanceof $pluginName.$modelName
            ) {

                // return the model
                return $Model;
            }
        }

        // obviously none was found, try looking in the plugin
        return ClassRegistry::init($model);
    }


    /**
     * given the model object, try and work out the plugin.name version of the model
     * incase any models have been extend, init method above can be used to load the model
     *
     * @param Object    Model Object
     * @return string   Model name in the form of Plugin.Model (or just Model if none plugin)
     */
    public static function getName($Model)
    {
        if (! empty($Model->plugin)) {

            return $Model->plugin . '.' . $Model->name;

        } else {

            $className = get_class($Model);
            $pluginName = str_replace($Model->name, '', $className);

            if (! empty($pluginName) && CakePlugin::loaded($pluginName)) {

                return $pluginName . '.' . $Model->name;
            }
        }

        return $Model->name;
    }
}
